function [X, W, out] = INDORT(S, r, conv, start)
% program for indort on quantification matrices min sum(k) SS( S(k)-X W(k) X' )
%
% input: S = [ S1...Sk]
%	 r: dimensionality of solution
%	 conv: convergence criterion
%	 start: (0=default; 1 =random start; 2 =current values for X)
%
% solution: W (rows containing W(k)'s) and X (n x r)
%
% uses ssq.m ed.m
% Written by Henk A.L. Kiers, University of Groningen

disp('r');disp(r);
disp('conv');disp(conv);
disp('start');disp(start);
[n,mn]=size(S);
m=mn/n;
W=[];

% initialize X

if start==0
  U=zeros(n,n);
  for k=1:m, U=U+S(:,(k-1)*n+1:k*n); end;
  [K,~,~] = svds(U,r);
  %[K,L]=ed(U);
  X=K(:,1:r);
end;

if start==1
  X=orth(rand(n,r)-.5);
  for k=1:m
    W(k,:)=(diag(X'*S(:,(k-1)*n+1:k*n)*X))';
  end;
end;

totssq=0;
lambda=zeros(1,m);
mu=zeros(1,m);
for k=1:m
   Sk=S(:,(k-1)*n+1:k*n); 
   %eiv(Sk); lambda(k)=ans(1);mu(k)=ans(n);
   W(k,:)=(diag(X'*Sk*X))';
   totssq=totssq+ssq(Sk);
end;

disp(' total ssq is ');
disp(totssq);
f=totssq-ssq(W);
fold=f+2*conv*f;
iter=0;
obj(iter+1) = f;
% set majorisation paramater
major=1;if sum(mu<0)==0,major=0;end;
t0=clock;
while abs(fold-f)>conv*f
  fold=f;
  iter=iter+1;
  U=zeros(n,r);
  nn=0;
  for k=1:m
    Sk=S(:,(k-1)*n+1:k*n); 
    U=U+Sk*X*diag(W(k,:));
 end;
 if major==1  % use majorisation approach
    alpha=0;
    dmax=max(W(k,:));
    dmin=min(W(k,:));
    for k=1:m
       alpha=alpha-min([dmax*lambda(k) dmin*lambda(k) dmax*mu(k) dmin*mu(k)]);
    end;   
    U=U+alpha*X;
  end;      
  X=U/(U'*U)^.5;
  for k=1:m
    W(k,:)=(diag(X'*S(:,(k-1)*n+1:k*n)*X))';
  end;
  f=totssq-ssq(W);
  if rem(iter,1)==0,
     fprintf(' indort value at iter %g is %16.12f ;  \n',iter,f);
  end;
  if fold<f, disp('Dysmonotony');end;
  obj(iter+1) = f;
end;    
fprintf(' Final indort value at iter %g is %16.12f \n',iter,f);
disp(' Elapsed time ');etime(clock,t0)
disp('');disp('')
out.obj = obj;
end