function [varExp_total, varExp_PCs] = representation_varExp(S,R,AHat,BHat)
% compute the variation expalined
% input:
%      S: same as in the INDScal model
%      R: number of PCs;
%      AHat: score matrix
%      BHat: loading matrix
% output:
%      varExp_total: variation explained.
%      varExp_PCs: variation explained for each PCs.

% total variation
[m,mn] = size(S); 
n = mn/m; % number of variables
ssq_S = norm(S,'fro')^2; % columne mean is 0.

% variation of model
ssq_model = 0;
for k=1:n
    model_Sk = AHat*diag(BHat(k,:))*AHat';
    ssq_model=ssq_model+norm(model_Sk,'fro')^2; % column mean is 0
end;

% compute variation explained by constructed model
varExp_total = ssq_model/ssq_S;

% compute the variation of each PCs
ssq_PCs = zeros(1,R);
for r=1:R
    ssq_tmp = 0;
    for k=1:n
        model_tmp = AHat(:,r)*diag(BHat(k,r))*AHat(:,r)';
        ssq_tmp=ssq_tmp+norm(model_tmp,'fro')^2;
    end
    ssq_PCs(1,r) = ssq_tmp;
end

% compute variation explained by each PC
varExp_PCs = ssq_PCs./ssq_S;

end

